@@ -1,12 +1,13 @@
-use strict; #-*-CPerl-*-
+use strict; #-*-CPerl-*- -*- hi-lock -*- 
 use warnings;
 
 use lib qw( ../../../lib );
 
 =head1 NAME
 
-    Algorithm::Evolutionary::Experiment - Class for setting up an experiment with algorithms and population
-                 
+Algorithm::Evolutionary::Experiment - Class for setting up an
+experiment with algorithms and population 
+
 =head1 SYNOPSIS
   
   use Algorithm::Evolutionary::Experiment;
@@ -14,13 +15,14 @@ use lib qw( ../../../lib );
   my $indiType = 'BitString';
   my $indiSize = 64;
   
-  my $ex = new  Algorithm::Evolutionary::Experiment $popSize, $indiType, $indiSize, $algorithm; #Algorithm might be anything of type Op
+  #Algorithm might be anything of type Op
+  my $ex = new Algorithm::Evolutionary::Experiment $popSize, $indiType, $indiSize, $algorithm; 
 
 
 =head1 DESCRIPTION
 
-Experiment contains an algorithm and a population, and applies one to
-the other. Contains both as instance variables. Can be serialized
+This class contains (as instance variables) an algorithm and a population, and applies one to
+the other.  Can be serialized
 using XML, and can read an XML description of the experiment. 
 
 =head1 METHODS
@@ -30,15 +32,15 @@ using XML, and can read an XML description of the experiment.
 package Algorithm::Evolutionary::Experiment;
 
 use Algorithm::Evolutionary::Utils qw(parse_xml);
-use Algorithm::Evolutionary::Individual::Base;
-use Algorithm::Evolutionary::Op::Base;
-use Algorithm::Evolutionary::Op::Creator;
+use Algorithm::Evolutionary qw(Individual::Base
+			       Op::Base
+			       Op::Creator );
 
-our ($VERSION) = ( '$Revision: 2.5 $ ' =~ / (\d+\.\d+)/ ) ;
+our $VERSION =   sprintf "%d.%03d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/g;
 
 use Carp;
 
-=head2 new( $pop_size, $type_of_individual, $individual_size
+=head2 new( $pop_size, $type_of_individual, $individual_size )
 
 Creates a new experiment. An C<Experiment> has two parts: the
    population and the algorithm. The population is created from a set
@@ -59,7 +61,8 @@ sub new ($$$$;$) {
     my $indiType = shift || carp "Empty individual class, can't create\n";
     my $indiSize = shift || carp "Empty individual size, no reasonable default, can't create\n";
     for ( my $i = 0; $i < $popSize; $i ++ ) {
-      my $indi = Algorithm::Evolutionary::Individual::Base::new( $indiType, { length => $indiSize } );
+      my $indi = Algorithm::Evolutionary::Individual::Base::new( $indiType, 
+								 { length => $indiSize } );
       $indi->randomize();
       push @{$self->{_pop}}, $indi;
     }
@@ -73,7 +76,7 @@ sub new ($$$$;$) {
 
 =head2 fromXML
 
-Creates a new experiment, same as before, but with an XML specification. An 
+Creates a new experiment, same as before, but with an L<XML> specification. An 
 example of it follows:
 
  <ea xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
@@ -109,9 +112,9 @@ example of it follows:
 
  </ea>
  
- This is an alternative constructor. Takes a well-formed string with the XML
- spec, which should have been done according to EvoSpec 0.3, or the same
- string processed with C<XML::Parser::EasyTree>, and returns a built experiment
+This is an alternative constructor. Takes a well-formed string with the XML
+spec, which should have been done according to EvoSpec 0.3, or the same
+string processed with C<XML::Parser::EasyTree>, and returns a built experiment
 
 =cut
 
@@ -193,7 +196,7 @@ sub asXML {
   my $str=<<'EOC';
 <ea version='0.4'>
 <!-- Serialization of an Experiment object. Generated automatically by
-     Experiment $Revision: 2.5 $ -->
+     Experiment $Revision: 3.2 $ -->
     <initial>
 EOC
 
@@ -209,16 +212,21 @@ EOC
   return $str;
 }
 
+=head2 SEE ALSO
+
+L<Algorithm::Evolutionary::Run> , another option for setting up
+experiments, which is the one you should rather use, as XML support is
+going to be deprecated (some day).
+
 =head1 Copyright
   
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/06 16:03:03 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Experiment.pm,v 2.5 2009/02/06 16:03:03 jmerelo Exp $ 
+  CVS Info: $Date: 2009/07/24 09:10:09 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Experiment.pm,v 3.2 2009/07/24 09:10:09 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.5 $
-  $Name $
+  $Revision: 3.2 $
 
 =cut
 
