@@ -5,7 +5,7 @@ use lib qw( ../../lib ../../../lib ../../../../lib);
 
 =head1 NAME
 
-  Algorithm::Evolutionary::Op::Bitflip - Bit-flip mutation
+Algorithm::Evolutionary::Op::Bitflip - Bit-flip mutation
 
 =head1 SYNOPSIS
 
@@ -36,13 +36,12 @@ does not need a rate
 
 package Algorithm::Evolutionary::Op::Bitflip;
 
-our ($VERSION) = ( '$Revision: 3.0 $ ' =~ /(\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 3.3 $ ' =~ /(\d+\.\d+)/ );
 
 use Carp;
-use Clone::Fast qw(clone);
+use Clone qw(clone);
 
-use Algorithm::Evolutionary::Op::Base;
-our @ISA = qw(Algorithm::Evolutionary::Op::Base);
+use base 'Algorithm::Evolutionary::Op::Base';
 
 #Class-wide constants
 our $ARITY = 1;
@@ -114,10 +113,10 @@ sub apply ($;$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/24 08:46:59 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Bitflip.pm,v 3.0 2009/07/24 08:46:59 jmerelo Exp $ 
+  CVS Info: $Date: 2011/02/13 17:45:53 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Bitflip.pm,v 3.3 2011/02/13 17:45:53 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.0 $
+  $Revision: 3.3 $
   $Name $
 
 =cut
