@@ -4,10 +4,10 @@ use warnings;
 =head1 NAME
 
 Algorithm::Evolutionary::Op::CanonicalGA - Canonical Genetic Algorithm, with any representation
-                 
 
 =head1 SYNOPSIS
 
+  # Straightforward instance, with all defaults (except for fitness function)
   my $algo = new Algorithm::Evolutionary::Op::CanonicalGA( $eval ); 
 
   #Define an easy single-generation algorithm with predefined mutation and crossover
@@ -38,14 +38,14 @@ package Algorithm::Evolutionary::Op::CanonicalGA;
 
 use lib qw(../../..);
 
-our ($VERSION) = ( '$Revision: 2.1 $ ' =~ / (\d+\.\d+)/ ) ;
+our $VERSION =   sprintf "%d.1%02d", q$Revision: 3.6 $ =~ /(\d+)\.(\d+)/g; # Hack for avoiding version mismatch
+
 
 use Carp;
-use Clone::Fast qw(clone);
 
-use Algorithm::Evolutionary::Wheel;
-use Algorithm::Evolutionary::Op::Bitflip;
-use Algorithm::Evolutionary::Op::QuadXOver;
+use Algorithm::Evolutionary qw(Wheel
+			       Op::Bitflip
+			       Op::QuadXOver );
 
 use base 'Algorithm::Evolutionary::Op::Easy';
 
@@ -103,6 +103,7 @@ sub apply ($) {
   }
 
   my @newPop;
+  @$pop = sort { $b->{_fitness} <=> $a->{_fitness} } @$pop;
   my @rates = map( $_->Fitness(), @$pop );
 
   #Creates a roulette wheel from the op priorities. Theoretically,
@@ -127,17 +128,29 @@ sub apply ($) {
 
 =head1 SEE ALSO
 
-L<Algorithm::Evolutionary::Op::Easy>.
+=over 4
+
+=item L<Algorithm::Evolutionary::Op::Easy>
+
+=item L<Algorithm::Evolutionary::Wheel>
+
+=item L<Algorithm::Evolutionary::Fitness::Base>
+
+=back
+
+Probably you will also be able to find a
+    L<canonical-genetic-algorithm.pl> example within this
+    bundle. Check it out for usage examples
 
 =head1 Copyright
   
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/04 20:43:14 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/CanonicalGA.pm,v 2.1 2009/02/04 20:43:14 jmerelo Exp $ 
+  CVS Info: $Date: 2011/02/14 06:55:36 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/CanonicalGA.pm,v 3.6 2011/02/14 06:55:36 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.1 $
+  $Revision: 3.6 $
   $Name $
 
 =cut
