@@ -6,6 +6,13 @@ rectangle-coverage.pl - Find the dot maximally covered by (random) rectangles
 
 =head1 SYNOPSIS
 
+You might have to do 
+
+  prompt% sudo cpan Tk 
+  prompt% sudo cpan Algorithm::RectanglesContainingDot 
+
+specially this last one, first, since that module is not installed by default with L<Algorithm::Evolutionary>.
+
   prompt% ./rectangle-coverage.pl <number-of-rectangles> <arena-side> <bits-per-coordinate> <population> <number of generations> <selection rate>
 
 Or
@@ -16,7 +23,7 @@ And change variable values from the user interface
 
 =head1 DESCRIPTION  
 
-A demo that combines the L<Algorithm::Evolutionary::Op::Easy> module
+A script that combines the L<Algorithm::Evolutionary::Op::Easy> module
     with L<Tk> to create a visual demo of the evolutionary
     algorithm. It generates randomly a number of rectangles, and shows
     how the population evolves to find the solution. The best point is
@@ -131,7 +138,7 @@ $mw->Button( -text    => 'Exit',
 	   )->pack( -side => 'left',
 		    -expand => 1 );
 
-$mw->eventAdd('<<Gen>>' => '<KeyPress>');
+$mw->eventAdd('<<Gen>>' => '<Control-Shift-G>'); # Improbable combination
 $mw->eventAdd('<<Fin>>' => '<Control-C>');
 $mw->bind('<<Gen>>' => \&generation);
 $mw->bind('<<Fin>>' => \&finished );
@@ -289,13 +296,13 @@ J. J. Merelo, C<jj (at) merelo.net>
 
 =head1 Copyright
   
-  This file is released under the GPL. See the LICENSE file included in this distribution,
-  or go to http://www.fsf.org/licenses/gpl.txt
+This file is released under the GPL. See the LICENSE file included in this distribution,
+or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/30 08:23:15 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/scripts/rectangle-coverage.pl,v 3.2 2009/07/30 08:23:15 jmerelo Exp $ 
+  CVS Info: $Date: 2012/07/09 15:46:15 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/scripts/rectangle-coverage.pl,v 3.4 2012/07/09 15:46:15 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.2 $
+  $Revision: 3.4 $
 
 =cut
 
